// BtChatServer.java

import java.io.*;
import javax.bluetooth.*;
import javax.microedition.lcdui.*;
import ch.aplu.gidlet.*;
import ch.aplu.bluetooth.*;

public class BtChatServer implements BtListener
{
  private final String serviceName = "ChatServer";
  private final boolean isVerbose = false;

  private BluetoothServer bs;
  private InputStreamReader isr;
  private OutputStreamWriter osw;
  private MForm form;
  private TextField tf;
  private TextArea ta;

  public BtChatServer()
  {
    if (isVerbose)
      VerboseWriter.init("e:/debug/BtChatServer.txt");
    form = new MForm("BtChat Server");
    tf = form.addInputField("Enter line to send:", "");
    ta = new TextArea("Response:", 5, 20);
    form.append(ta);
    form.addOkButton();
    form.show();
    bs = new BluetoothServer(serviceName, this, isVerbose);
    say("Running as server");
    say("Wait for connection..");

  }

  public void sendLine()
  {
    String line = tf.getString();
    tf.setString("");
    try
    {
      osw.write(line, 0, line.length());
      osw.write('\r');
      osw.write('\n');
      osw.flush();
    }
    catch (Exception ex)
    {
      // osw may be null
    }
  }

  public void notifyConnection(RemoteDevice rd,
                               InputStream is, OutputStream os)
  {
    isr = new InputStreamReader(is);
    osw = new OutputStreamWriter(os);

    try
    {
      say("Connected to '" + rd.getFriendlyName(false) + "'");
    }
    catch (Exception ex)
    {
      say("Exception in getFriendlyName()");
      return;
    }

    try
    {
      while(true)
      {
        int ch;
        String line = "";
        while ((ch = isr.read()) != -1)
        {
          line += (char)ch;
          if (ch == '\n')
          {
            say(line);
            line = "";
          }
        }
        throw new IOException();
      }
    }
    catch (IOException ex)
    {
      say("Connection lost");
      say("Wait for a client..");
    }
    bs.close();
  }

  public void say(String line)
  {
    ta.append(line);
  }

  public void close()
  {
    if (bs != null)
      bs.close();
  }

  public void cancel()
  {
    if (bs != null)
      bs.cancel();
  }
}
