// CarpetGidlet.java
/*
 * This is a Sierpinski fractal.
 * With probability 1/8 do the following:
 * divides the current (x, y) value by 3
 * and add either 1/3 or 2/3 to x, or to y, or to both.
 * In order to create the Sierpinski carpet holes,
 * give zero probability to
 * xnew = x/3 + 1.0/3  xnew = y/3 + 1.0/3
 */

import ch.aplu.gidlet.*;
import java.util.Random;

public class CarpetGidlet extends Gidlet
{
  public void main()
  {
    final int MAXITERATIONS = 30000;
    MPanel p = new MPanel("Sierpinski fractal", -0.1, 1.1, -0.1, 1.1);
    p.bgColor(BLUE);
    p.color(YELLOW);
    p.setTitle("Carpet");

    double x = 1, y = 1;
    double dx = 0, dy = 0;
    Random rnd = new Random();
    int r;

    for (int i = 0; i < MAXITERATIONS; i++)
    {
      r = rnd.nextInt(8);
      switch (r)
      {
        case 0:
          dx = 0;
          dy = 0;
          break;
        case 1:
          dx = 1;
          dy = 0;
          break;
        case 2:
          dx = 0;
          dy = 1;
          break;
        case 3:
          dx = 1;
          dy = 2;
          break;
        case 4:
          dx = 0;
          dy = 2;
          break;
        case 5:
          dx = 2;
          dy = 0;
          break;
        case 6:
          dx = 2;
          dy = 1;
          break;
        case 7:
          dx = 2;
          dy = 2;
          break;
      }
      x = x / 3 + dx / 3;
      y = y / 3 + dy / 3;
      p.point(x, y);
    }
    p.color(WHITE);
    p.move(0.5, 0.5);
    p.rectangle(1, 1);
  }
}



