// VocSelectGidlet.java

import ch.aplu.gidlet.*;
import javax.microedition.lcdui.*;

public class VocSelectGidlet extends Gidlet implements ItemStateListener
{
  // ------------- Inner class MyCommandListener -------------

  private class MyCommandListener implements CommandListener
  {

    public void commandAction(Command c, Displayable d)
    {
      if (c == exitCommand)
        notifyDestroyed();

      if (c == nextCommand)
      {
        curIndex++;
        if (curIndex == nbRecords)
        {
          tf1.setString("");
          tf2.setString("");
          si.setText("Lesson finished");
          f.removeCommand(nextCommand);
          f.removeCommand(showCommand);
          f.addCommand(exitCommand);
        }
        else
        {
          tf1.setString(question[curIndex]);
          tf2.setString("");
          si.setText("Record: " + (curIndex + 1) + " of " + nbRecords);
          f.removeCommand(exitCommand);
          f.addCommand(showCommand);
        }
      }

      if (c == showCommand)
      {
        tf2.setString(answer[curIndex]);
        f.removeCommand(showCommand);
        f.addCommand(exitCommand);
      }
    }
  }
  // ------------- End of inner class ------------------------

  private MForm f;
  private MFile mf = new MFile();
  private TextField tf1;
  private TextField tf2;
  private StringItem si;
  private Command nextCommand = new Command("Next", Command.OK, 1);
  private Command showCommand = new Command("Show", Command.EXIT, 1);
  private Command exitCommand = new Command("Exit", Command.EXIT, 1);
  private String[] question;
  private String[] answer;
  private int nbRecords; // Total nb of records
  private int curIndex; // Current record index
  private ChoiceGroup cg =
    new ChoiceGroup("Select Lesson: ", Choice.POPUP);
  private int nbLessons = 1;

  public void main()
  {
    f = new MForm("VocSelectGidlet");
    f.show();
    if (!selectLesson())
    {
      f.addOutputField().
        setText("Read of vocabulary file(s) failed");
      return;
    }
    getRecords();
    if (nbRecords == 0)
    {
      f.addOutputField().
        setText("Vocabulary file empty");
      return;
    }
    initForm();
    curIndex = 0;
    si.setText("Record: 1 of " + nbRecords);
    tf1.setString(question[curIndex]);
  }

  private boolean selectLesson()
  // Return true, if successful, otherwise false
  {
    mf.findFirstRoot();
    if (mf.getPath().equals("c:/"))  // No access on c:, try next
      mf.findNextRoot();
    String dirPath = mf.getPath() + "voc/";
    mf.setPath(dirPath);
    if (!mf.exists())  // Directory does not exist
      return false;

    if (!mf.findFirst())  // Search for first lesson
      return false; // No lesson

    // Fill choice group
    cg.append(mf.getPath(), null);
    while (mf.findNext())
    {
      nbLessons++;
      cg.append(mf.getPath(), null);
    }
    mf.setPath(dirPath);          // Restore path
    f.setItemStateListener(this); // Register listener
    f.append(cg);                 // Show choice group
    putSleep();                   // Wait for selection
    return true;
  }

  private void initForm()
  {
    f.delete(0);  // Remove choice group
    tf1 = f.addInputField("Deutsch:", "");
    tf2 = f.addInputField("English:", "");
    f.addOutputField().setText("Voc file: " + mf.getPath() + "\n");
    si = f.addOutputField();

    f.removeExitButton();
    f.addCommand(nextCommand);
    f.addCommand(showCommand);
    f.setCommandListener(new MyCommandListener());
  }

  private void getRecords()
  {
    String content = mf.read();

    if (content.equals("")) // Empty file
    {
      nbRecords = 0;
      return;
    }

    String[] records = split(content, "\r\n");
    nbRecords = records.length - 1;
    question = new String[nbRecords];
    answer = new String[nbRecords];

    for (int i = 0; i < nbRecords; i++)
    {
      String[] parts = split(records[i], "|");
      question[i] = parts[0];
      answer[i] = parts[1];
    }
  }

  // Implements ItemStateListener
  public void itemStateChanged(Item item)
  {
    String lesson = "";
    for (int i = 0; i < nbLessons; i++)
      if (cg.isSelected(i))
        lesson = cg.getString(i);
    mf.setPath(mf.getPath() + lesson);
    wakeUp();
  }
}




