// VerboseWriter.java

/*
This software is part of the Aplu Bluetooth Library.
It is Open Source Free Software, so you may
- run the code for any purpose
- study how the code works and adapt it to your needs
- integrate all or parts of the code in your own programs
- redistribute copies of the code
- improve the code and release your improvements to the public
However the use of the code is entirely your responsibility.
 */

package ch.aplu.bluetooth;

import java.io.*;
import ch.aplu.gidlet.*;
import java.util.Date;

/**
 * Class to output text information either to System.out or into a log file.
 * Inovke VerboseWriter.out.println() to write the information.
 */
public class VerboseWriter
{
  private static MFile mf = null;

  /**
   * PrintStream object reference.
   */
  public static PrintStream out = System.out;

  /**
   * Redirects output to the given log file. Use JSR75 (FileConnection) format
   * of path: rootdevice/dir/../file.ext. See class MFile for more information.
   * The content of an existing file is erased.
   * @see ch.aplu.gidlet.MFile
   */
  public synchronized static void init(String logpath)
  {
    mf = new MFile(logpath);
    mf.createFile();
    out = new PrintStream(mf.getOutputStream());
    out.println("Log started at: " + new Date());
  }

  /**
   * Closes the log file.
   */
   public synchronized static void close()
  {
    if (mf != null)
      mf.releaseConnection();
  }
}
